@@ -10,6 +10,7 @@ pub mod editor;
 pub mod editor_utils;
 pub mod events;
 pub mod glob;
+pub mod help;
 pub mod history;
 pub mod json;
 pub mod keymap;
@@ -68,14 +69,16 @@ fn print_help() {
     println!("  --server                 only run as server (ignores files and configs arguments)");
     println!("  -c, --config             sources config file at path (repeatable)");
     println!("  --try-config             tries to source a config file at path, throws no error if fails (repeatable)");
-    println!("  --no-default-config      does not source the default config included in the editor");
+    println!(
+        "  --no-default-config      does not source the default config included in the editor"
+    );
 }
 
 impl Args {
     pub fn parse() -> Self {
         fn error(message: std::fmt::Arguments) -> ! {
             println!("{}", message);
-            std::process::exit(0);
+            std::process::exit(1);
         }
 
         fn arg_to_str(arg: &std::ffi::OsString) -> &str {
