@@ -622,7 +622,8 @@ impl WorkspaceEdit {
                             let buffer = editor.buffers.add_new();
                             buffer.capabilities = BufferCapabilities::log();
                             buffer.capabilities.can_save = true;
-                            buffer.set_path(path);
+                            buffer.path.clear();
+                            buffer.path.push(path);
                             let _ = buffer.discard_and_reload_from_file(
                                 &mut editor.word_database,
                                 &mut editor.events,
