@@ -1,11 +1,12 @@
 use crate::{
-    command::{replace_to_between_text_markers, CommandManager},
+    command::CommandManager,
     editor::KeysIterator,
     editor_utils::{MessageKind, ReadLinePoll},
     lsp,
     mode::{Mode, ModeContext, ModeKind, ModeOperation, ModeState},
     picker::EntrySource,
     platform::Key,
+    register::RETURN_REGISTER,
     word_database::WordIndicesIter,
 };
 
@@ -13,7 +14,6 @@ pub struct State {
     on_client_keys:
         fn(ctx: &mut ModeContext, &mut KeysIterator, ReadLinePoll) -> Option<ModeOperation>,
     continuation: Option<String>,
-    entry_var_name: String,
     lsp_client_handle: Option<lsp::ClientHandle>,
 }
 
@@ -22,7 +22,6 @@ impl Default for State {
         Self {
             on_client_keys: |_, _, _| None,
             continuation: None,
-            entry_var_name: String::new(),
             lsp_client_handle: None,
         }
     }
@@ -45,6 +44,7 @@ impl ModeState for State {
             &mut ctx.editor.string_pool,
             &ctx.editor.buffered_keys,
             keys,
+            &ctx.editor.registers,
         );
         if let ReadLinePoll::Pending = poll {
             keys.put_back();
@@ -96,7 +96,7 @@ pub mod buffer {
 
     use std::path::Path;
 
-    use crate::{buffer::Buffer, navigation_history::NavigationHistory};
+    use crate::navigation_history::NavigationHistory;
 
     pub fn enter_mode(ctx: &mut ModeContext) {
         fn on_client_keys(
@@ -144,13 +144,7 @@ pub mod buffer {
         ctx.editor.read_line.set_prompt("buffer:");
         ctx.editor.picker.clear();
 
-        for path in ctx
-            .editor
-            .buffers
-            .iter()
-            .map(Buffer::path)
-            .filter_map(Path::to_str)
-        {
+        for path in ctx.editor.buffers.iter().filter_map(|b| b.path.to_str()) {
             ctx.editor.picker.add_custom_entry(path);
         }
 
@@ -282,7 +276,7 @@ pub mod lsp_document_symbol {
 pub mod custom {
     use super::*;
 
-    pub fn enter_mode(ctx: &mut ModeContext, continuation: &str, entry_var_name: &str) {
+    pub fn enter_mode(ctx: &mut ModeContext, continuation: String) {
         fn on_client_keys(
             ctx: &mut ModeContext,
             _: &mut KeysIterator,
@@ -291,15 +285,13 @@ pub mod custom {
             match poll {
                 ReadLinePoll::Pending => None,
                 ReadLinePoll::Submitted => {
-                    let mut continuation =
-                        ctx.editor.mode.picker_state.continuation.take().unwrap();
-                    let entry_var_name = &ctx.editor.mode.picker_state.entry_var_name;
+                    let continuation = ctx.editor.mode.picker_state.continuation.take().unwrap();
                     let entry = ctx.editor.picker.current_entry(&ctx.editor.word_database);
 
                     let mut operation = None;
                     if let Some((_, entry)) = entry {
-                        replace_to_between_text_markers(&mut continuation, entry_var_name, entry);
-                        operation = CommandManager::eval_commands_then_output(
+                        ctx.editor.registers.set(RETURN_REGISTER, entry);
+                        operation = CommandManager::eval_and_then_output(
                             ctx.editor,
                             ctx.platform,
                             ctx.clients,
@@ -331,11 +323,8 @@ pub mod custom {
 
         let state = &mut ctx.editor.mode.picker_state;
         state.on_client_keys = on_client_keys;
-        state.continuation = Some(ctx.editor.string_pool.acquire_with(continuation));
-        state.entry_var_name.clear();
-        state.entry_var_name.push_str(entry_var_name);
+        state.continuation = Some(continuation);
 
         Mode::change_to(ctx, ModeKind::Picker);
     }
 }
-
